@@ -4,7 +4,7 @@
 
 ;; Maintainer: Nicolas P. Rougier <Nicolas.Rougier@inria.fr>
 ;; URL: https://github.com/rougier/nano-modeline
-;; Version: 0.7.1
+;; Version: 0.7.2
 ;; Package-Requires: ((emacs "27.1"))
 ;; Keywords: convenience, mode-line, header-line
 
@@ -48,6 +48,11 @@
 ;;
 ;;; NEWS:
 ;;
+;; Version 0.7.2
+;; - Fix a bug in info mode (breadcrumbs)
+;; - Fix mu header mode for version 1.8
+;; - Put back padding (for default style)
+;;
 ;; Version 0.7.1
 ;; - Fix a bug with mu4e-dashboard
 ;; - Fix a bug in pdf view mode
@@ -142,7 +147,7 @@ Negative is downwards."
                  (const :tag "Icon" icon))
   :group 'nano-modeline)
 
-(defcustom nano-modeline-prefix-padding nil
+(defcustom nano-modeline-prefix-padding t
   "Wheter to add a space after prefix part.
 
 This is useful (aesthetically) if the face of prefix uses a different background color than the rest of the modeline."
@@ -634,26 +639,27 @@ KEY mode name, for reference only. Easier to do lookups and/or replacements.
         (crumbs ())
         (depth Info-breadcrumbs-depth)
     line)
-    (while  (> depth 0)
-      (setq node (nth 1 (assoc node nodes)))
-      (if node (push node crumbs))
-      (setq depth (1- depth)))
-    (setq crumbs (cons "Top" (if (member (pop crumbs) '(nil "Top"))
-                     crumbs (cons nil crumbs))))
-    (forward-line 1)
-    (dolist (node crumbs)
-      (let ((text
-         (if (not (equal node "Top")) node
-           (format "%s"
-               (if (stringp Info-current-file)
-               (file-name-sans-extension
-                (file-name-nondirectory Info-current-file))
-             Info-current-file)))))
-    (setq line (concat line (if (null line) "" " > ")
-                                (if (null node) "..." text)))))
-    (if (and cnode (not (equal cnode "Top")))
-        (setq line (concat line (if (null line) "" " > ") cnode)))
-    line))
+    (save-excursion
+      (while  (> depth 0)
+        (setq node (nth 1 (assoc node nodes)))
+        (if node (push node crumbs))
+        (setq depth (1- depth)))
+      (setq crumbs (cons "Top" (if (member (pop crumbs) '(nil "Top"))
+                       crumbs (cons nil crumbs))))
+      (forward-line 1)
+      (dolist (node crumbs)
+        (let ((text
+           (if (not (equal node "Top")) node
+             (format "%s"
+                 (if (stringp Info-current-file)
+                 (file-name-sans-extension
+                  (file-name-nondirectory Info-current-file))
+               Info-current-file)))))
+      (setq line (concat line (if (null line) "" " > ")
+                                  (if (null node) "..." text)))))
+      (if (and cnode (not (equal cnode "Top")))
+          (setq line (concat line (if (null line) "" " > ") cnode)))
+      line)))
 
 (defun nano-modeline-info-mode-p ()
   (derived-mode-p 'Info-mode))
@@ -732,9 +738,9 @@ KEY mode name, for reference only. Easier to do lookups and/or replacements.
 (defun nano-modeline-mu4e-server-props ()
   "Encapsulates the call to the variable mu4e-/~server-props
 depending on the version of mu4e."
-  (if (version< "1.6.10" mu4e-mu-version)
-      mu4e--server-props
-    mu4e~server-props))
+  (if (version< mu4e-mu-version "1.6.0")
+      mu4e~server-props
+    mu4e--server-props))
 
 (defun nano-modeline-mu4e-activate ()
   (with-eval-after-load 'mu4e
@@ -788,7 +794,7 @@ depending on the version of mu4e."
 
 ;; ---------------------------------------------------------------------
 (defun nano-modeline-mu4e-quote (str)
-  (if (version< "1.6.5" mu4e-mu-version)
+  (if (version< mu4e-mu-version "1.8.0")
       (mu4e~quote-for-modeline str)
     (mu4e-quote-for-modeline str)))
 
@@ -796,7 +802,7 @@ depending on the version of mu4e."
   (derived-mode-p 'mu4e-headers-mode))
 
 (defun nano-modeline-mu4e-headers-mode ()
-  (let ((mu4e-modeline-max-width 80))
+  (let ((mu4e-modeline-max-width 120))
     (nano-modeline-render (plist-get (cdr (assoc 'mu4e-headers-mode nano-modeline-mode-formats)) :icon)
                           "Search:"
                           (or (nano-modeline-mu4e-quote
